==> servicecatalog-1.0.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/servicecatalog/CfnPortfolioProps.java <==
package software.amazon.awscdk.services.servicecatalog;

/**
 * Properties for defining a `AWS::ServiceCatalog::Portfolio`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.0 (build a586a1a)", date = "2019-07-11T14:10:48.399Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface CfnPortfolioProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::ServiceCatalog::Portfolio.DisplayName`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-displayname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDisplayName();
    /**
     * `AWS::ServiceCatalog::Portfolio.ProviderName`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-providername
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getProviderName();
    /**
     * `AWS::ServiceCatalog::Portfolio.AcceptLanguage`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-acceptlanguage
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getAcceptLanguage();
    /**
     * `AWS::ServiceCatalog::Portfolio.Description`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getDescription();
    /**
     * `AWS::ServiceCatalog::Portfolio.Tags`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.util.List<software.amazon.awscdk.core.CfnTag> getTags();

    /**
     * @return a {@link Builder} of {@link CfnPortfolioProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnPortfolioProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Builder {
        private java.lang.String _displayName;
        private java.lang.String _providerName;
        @javax.annotation.Nullable
        private java.lang.String _acceptLanguage;
        @javax.annotation.Nullable
        private java.lang.String _description;
        @javax.annotation.Nullable
        private java.util.List<software.amazon.awscdk.core.CfnTag> _tags;

        /**
         * Sets the value of DisplayName
         * @param value `AWS::ServiceCatalog::Portfolio.DisplayName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withDisplayName(final java.lang.String value) {
            this._displayName = java.util.Objects.requireNonNull(value, "displayName is required");
            return this;
        }
        /**
         * Sets the value of ProviderName
         * @param value `AWS::ServiceCatalog::Portfolio.ProviderName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withProviderName(final java.lang.String value) {
            this._providerName = java.util.Objects.requireNonNull(value, "providerName is required");
            return this;
        }
        /**
         * Sets the value of AcceptLanguage
         * @param value `AWS::ServiceCatalog::Portfolio.AcceptLanguage`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withAcceptLanguage(@javax.annotation.Nullable final java.lang.String value) {
            this._acceptLanguage = value;
            return this;
        }
        /**
         * Sets the value of Description
         * @param value `AWS::ServiceCatalog::Portfolio.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withDescription(@javax.annotation.Nullable final java.lang.String value) {
            this._description = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value `AWS::ServiceCatalog::Portfolio.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder withTags(@javax.annotation.Nullable final java.util.List<software.amazon.awscdk.core.CfnTag> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnPortfolioProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public CfnPortfolioProps build() {
            return new CfnPortfolioProps() {
                private final java.lang.String $displayName = java.util.Objects.requireNonNull(_displayName, "displayName is required");
                private final java.lang.String $providerName = java.util.Objects.requireNonNull(_providerName, "providerName is required");
                @javax.annotation.Nullable
                private final java.lang.String $acceptLanguage = _acceptLanguage;
                @javax.annotation.Nullable
                private final java.lang.String $description = _description;
                @javax.annotation.Nullable
                private final java.util.List<software.amazon.awscdk.core.CfnTag> $tags = _tags;

                @Override
                public java.lang.String getDisplayName() {
                    return this.$displayName;
                }

                @Override
                public java.lang.String getProviderName() {
                    return this.$providerName;
                }

                @Override
                public java.lang.String getAcceptLanguage() {
                    return this.$acceptLanguage;
                }

                @Override
                public java.lang.String getDescription() {
                    return this.$description;
                }

                @Override
                public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
                    return this.$tags;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("displayName", om.valueToTree(this.getDisplayName()));
                    obj.set("providerName", om.valueToTree(this.getProviderName()));
                    if (this.getAcceptLanguage() != null) {
                        obj.set("acceptLanguage", om.valueToTree(this.getAcceptLanguage()));
                    }
                    if (this.getDescription() != null) {
                        obj.set("description", om.valueToTree(this.getDescription()));
                    }
                    if (this.getTags() != null) {
                        obj.set("tags", om.valueToTree(this.getTags()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.servicecatalog.CfnPortfolioProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::ServiceCatalog::Portfolio.DisplayName`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-displayname
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getDisplayName() {
            return this.jsiiGet("displayName", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::Portfolio.ProviderName`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-providername
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getProviderName() {
            return this.jsiiGet("providerName", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::Portfolio.AcceptLanguage`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-acceptlanguage
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getAcceptLanguage() {
            return this.jsiiGet("acceptLanguage", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::Portfolio.Description`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-description
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.lang.String getDescription() {
            return this.jsiiGet("description", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::Portfolio.Tags`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-tags
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @javax.annotation.Nullable
        public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.jsiiGet("tags", java.util.List.class);
        }
    }
}

==> servicecatalog-1.1.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/servicecatalog/CfnPortfolioProps.java <==
package software.amazon.awscdk.services.servicecatalog;

/**
 * Properties for defining a `AWS::ServiceCatalog::Portfolio`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.14.2 (build e881f16)", date = "2019-07-19T19:04:13.283Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
public interface CfnPortfolioProps extends software.amazon.jsii.JsiiSerializable {
    /**
     * `AWS::ServiceCatalog::Portfolio.DisplayName`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-displayname
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getDisplayName();
    /**
     * `AWS::ServiceCatalog::Portfolio.ProviderName`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-providername
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getProviderName();
    /**
     * `AWS::ServiceCatalog::Portfolio.AcceptLanguage`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-acceptlanguage
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getAcceptLanguage();
    /**
     * `AWS::ServiceCatalog::Portfolio.Description`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-description
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.lang.String getDescription();
    /**
     * `AWS::ServiceCatalog::Portfolio.Tags`.
     * 
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-tags
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    java.util.List<software.amazon.awscdk.core.CfnTag> getTags();

    /**
     * @return a {@link Builder} of {@link CfnPortfolioProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    static Builder builder() {
        return new Builder();
    }

    /**
     * A builder for {@link CfnPortfolioProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
    final class Builder {
        private java.lang.String _displayName;
        private java.lang.String _providerName;
        @javax.annotation.Nullable
        private java.lang.String _acceptLanguage;
        @javax.annotation.Nullable
        private java.lang.String _description;
        @javax.annotation.Nullable
        private java.util.List<software.amazon.awscdk.core.CfnTag> _tags;

        /**
         * Sets the value of DisplayName
         * @param value `AWS::ServiceCatalog::Portfolio.DisplayName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withDisplayName(final java.lang.String value) {
            this._displayName = java.util.Objects.requireNonNull(value, "displayName is required");
            return this;
        }
        /**
         * Sets the value of ProviderName
         * @param value `AWS::ServiceCatalog::Portfolio.ProviderName`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withProviderName(final java.lang.String value) {
            this._providerName = java.util.Objects.requireNonNull(value, "providerName is required");
            return this;
        }
        /**
         * Sets the value of AcceptLanguage
         * @param value `AWS::ServiceCatalog::Portfolio.AcceptLanguage`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withAcceptLanguage(@javax.annotation.Nullable final java.lang.String value) {
            this._acceptLanguage = value;
            return this;
        }
        /**
         * Sets the value of Description
         * @param value `AWS::ServiceCatalog::Portfolio.Description`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withDescription(@javax.annotation.Nullable final java.lang.String value) {
            this._description = value;
            return this;
        }
        /**
         * Sets the value of Tags
         * @param value `AWS::ServiceCatalog::Portfolio.Tags`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public Builder withTags(@javax.annotation.Nullable final java.util.List<software.amazon.awscdk.core.CfnTag> value) {
            this._tags = value;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link CfnPortfolioProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public CfnPortfolioProps build() {
            return new CfnPortfolioProps() {
                private final java.lang.String $displayName = java.util.Objects.requireNonNull(_displayName, "displayName is required");
                private final java.lang.String $providerName = java.util.Objects.requireNonNull(_providerName, "providerName is required");
                @javax.annotation.Nullable
                private final java.lang.String $acceptLanguage = _acceptLanguage;
                @javax.annotation.Nullable
                private final java.lang.String $description = _description;
                @javax.annotation.Nullable
                private final java.util.List<software.amazon.awscdk.core.CfnTag> $tags = _tags;

                @Override
                public java.lang.String getDisplayName() {
                    return this.$displayName;
                }

                @Override
                public java.lang.String getProviderName() {
                    return this.$providerName;
                }

                @Override
                public java.lang.String getAcceptLanguage() {
                    return this.$acceptLanguage;
                }

                @Override
                public java.lang.String getDescription() {
                    return this.$description;
                }

                @Override
                public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
                    return this.$tags;
                }

                public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                    com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                    com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                    obj.set("displayName", om.valueToTree(this.getDisplayName()));
                    obj.set("providerName", om.valueToTree(this.getProviderName()));
                    if (this.getAcceptLanguage() != null) {
                        obj.set("acceptLanguage", om.valueToTree(this.getAcceptLanguage()));
                    }
                    if (this.getDescription() != null) {
                        obj.set("description", om.valueToTree(this.getDescription()));
                    }
                    if (this.getTags() != null) {
                        obj.set("tags", om.valueToTree(this.getTags()));
                    }
                    return obj;
                }

            };
        }
    }

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.servicecatalog.CfnPortfolioProps {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
            super(mode);
        }

        /**
         * `AWS::ServiceCatalog::Portfolio.DisplayName`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-displayname
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.lang.String getDisplayName() {
            return this.jsiiGet("displayName", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::Portfolio.ProviderName`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-providername
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        public java.lang.String getProviderName() {
            return this.jsiiGet("providerName", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::Portfolio.AcceptLanguage`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-acceptlanguage
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getAcceptLanguage() {
            return this.jsiiGet("acceptLanguage", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::Portfolio.Description`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-description
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.lang.String getDescription() {
            return this.jsiiGet("description", java.lang.String.class);
        }

        /**
         * `AWS::ServiceCatalog::Portfolio.Tags`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-servicecatalog-portfolio.html#cfn-servicecatalog-portfolio-tags
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.External)
        @javax.annotation.Nullable
        public java.util.List<software.amazon.awscdk.core.CfnTag> getTags() {
            return this.jsiiGet("tags", java.util.List.class);
        }
    }
}
